@@ -1,17 +1,15 @@
 package Net::Whois::Raw::Data;
 
 use strict;
-use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
 
-@www_whois = qw(
+our @www_whois = qw(
     IN
-    KZ
     SPB.RU
     MSK.RU
 );
 
-%servers = qw(
-    NS     whois.internic.net
+our %servers = qw(
+    NS     whois.nsiregistry.net
     RIPE   whois.ripe.net
     IP     whois.arin.net
 
@@ -70,7 +68,7 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     JP  whois.jprs.jp
     KE  whois.kenic.or.ke
     KR  whois.nic.or.kr
-    KZ  www.nic.kz
+    KZ  whois.nic.kz
     LA  whois2.afilias-grs.net
     LI  whois.nic.li
     LT  whois.domreg.lt
@@ -146,17 +144,35 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     RU.NET	whois.relcom.ru
     YES.RU	whois.regtime.net
 
-    UK.COM      whois.centralnic.com
-    UK.NET      whois.centralnic.com
-    GB.COM      whois.centralnic.com
-    GB.NET      whois.centralnic.com
     EU.COM      whois.centralnic.com
+    GB.COM      whois.centralnic.com
+    KR.COM	whois.centralnic.com
+    US.COM	whois.centralnic.com
+    QC.COM	whois.centralnic.com
+    DE.COM	whois.centralnic.com
+    NO.COM	whois.centralnic.com
+    HU.COM	whois.centralnic.com
+    JPN.COM	whois.centralnic.com
+    UY.COM	whois.centralnic.com
+    ZA.COM	whois.centralnic.com
+    BR.COM	whois.centralnic.com
+    CN.COM	whois.centralnic.com
+    SA.COM	whois.centralnic.com
+    SE.COM	whois.centralnic.com
+    UK.COM      whois.centralnic.com
+    RU.COM	whois.centralnic.com
+
+    GB.NET      whois.centralnic.com
+    UK.NET      whois.centralnic.com
+    SE.NET	whois.centralnic.com
+
+    AE.ORG	whois.centralnic.com
 );
 
 # These serve only several subdomains
 #         ZA  apies.frd.ac.za
 
-%ip_whois_servers = qw(
+our %ip_whois_servers = qw(
     AFRINIC	whois.afrinic.net
     APNIC	whois.apnic.net
     ARIN	whois.arin.net
@@ -168,7 +184,7 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
 );
 
 
-%notfound = (
+our %notfound = (
     'whois.arin.net' => '^No match for',
     'whois.ripe.net' => 'No entries found',
 
@@ -177,7 +193,7 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     'whois.afilias.net' => '^NOT FOUND',
     'whois.nic.mil' => '^No match for',
     'whois.museum' => '^No information for',
-
+    'whois.nic.kz' => 'Nothing found for this query',
     'whois.nic.at' => 'nothing found',
     'whois.aunic.net' => 'No Data Found',
     'whois.dns.be' => '^Status:      FREE',
@@ -197,7 +213,7 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     'whois.isoc.org.il' => 'No data was found',
     'whois.inregistry.net' => '^No matches',
     'whois.isnic.is' => 'No entries found',
-    'whois.nic.it' => '^No entries found',
+    'whois.nic.it' => 'Status:             AVAILABLE',
     'whois.jprs.jp' => 'No match',
     'whois.nic.or.kr' => 'Above domain name is not registered',
     'whois2.afilias-grs.net' => '^NO MATCH for',
@@ -240,7 +256,7 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     'whois.thnic.net' => 'No entries found',
 );
 
-%strip = (
+our %strip = (
     'whois.crsnic.net' => [
 	'^TERMS OF USE:',
 	'^database through',
@@ -587,9 +603,35 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
 	'^----------------------------------',
 	'^Database last updated',
     ],
+    'whois.dotmobiregistry.net' => [
+	'^mTLD WHOIS LEGAL STATEMENT',
+	'^by mTLD and the access to',
+	'^for information purposes only.',
+	'^domain name is still available',
+	'^the registration records of',
+	'^circumstances, be held liable',
+	'^be wrong, incomplete, or not',
+	'^you agree not to use the information',
+	'^otherwise support the transmission',
+	'^other solicitations whether via',
+	'^possible way; or to cause',
+	'^sending \(whether by automated,',
+	'^volumes or other possible means\)',
+	'^above, it is explicitly forbidden',
+	'^in any form and by any means',
+	'^quantitatively or qualitatively',
+	'^database without prior and explicit',
+	'^hereof, or to apply automated,',
+	'^You agree that any reproduction',
+	'^purposes will always be considered',
+	'^the content of the WHOIS database.',
+	'^by this policy and accept that mTLD',
+	'^WHOIS services in order to protect',
+	'^integrity of the database.',
+    ],
 );
 
-%exceed = (
+our %exceed = (
     'whois.eu' => 'Excessive querying, grace period of',
     'whois.dns.lu' => 'Excessive querying, grace period of',
     'whois.mynic.net.my' => 'Query limitation is',
@@ -598,4 +640,8 @@ use vars qw(%notfound %strip %servers %exceed @www_whois %ip_whois_servers);
     'whois.nic.uk' => 'and will be replenished',
 );
 
+our %postprocess = (
+    'whois.net.ua' => sub {  },
+);
+
 1;
